#
# spec file for package libqca-qt5
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1320
# Disable PKCS11 on TW, conflicts with older openssl
%bcond_with pkcs11
%else
%bcond_without pkcs11
%endif

%define _so 2
Name:           libqca-qt5
Version:        2.1.3
Release:        lp150.2.8
Summary:        Qt Cryptographic Architecture 2
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            https://userbase.kde.org/QCA
Source:         http://download.kde.org/stable/qca/%{version}/src/qca-%{version}.tar.xz
Source1:        baselibs.conf
Source99:       libqca-qt5-rpmlintrc
# PATCH-FIX-UPSTREAM (Needed for 0002 to apply)
Patch1:         0001-Revert-tlsunittest-disable-some-ciphers.patch
# PATCH-FIX-UPSTREAM (Variant of 0001, but for master)
Patch2:         0002-Disable-missed-openssl-cipher-suites.patch
# PATCH-FIX-UPSTREAM
Patch3:         0003-Add-support-for-OpenSSL-1.1.0.patch
# PATCH-FIX-OPENSUSE (Needed for gcrypt on 42.x?)
Patch100:       ansi.diff
BuildRequires:  ca-certificates
BuildRequires:  cmake >= 2.8.12
BuildRequires:  cyrus-sasl-devel
BuildRequires:  gpg2
BuildRequires:  libdrm-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libjpeg-devel
BuildRequires:  mozilla-nss-devel
BuildRequires:  pkgconfig(openssl)
%if %{with pkcs11}
BuildRequires:  pkcs11-helper-devel
%endif
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Network) >= 5.2.0
Requires:       gpg2 >= 2.0.0
Recommends:     %{name}-plugins
Provides:       libqca-qt5-2 = %{version}
Obsoletes:      libqca-qt5-2 < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.

%package devel
Summary:        Development files for the Qt Cryptographic Architecture 2
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       pkgconfig(Qt5Core) >= 5.2.0
Requires:       pkgconfig(Qt5Network) >= 5.2.0

%description devel
This package provides a generic Qt cryptographic architecture,
including a library and a plugin for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES and AES.

%package plugins
Summary:        Various plugins for the Qt Cryptographic Architecture 2
Group:          System/Libraries

%description plugins
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.

%prep
%setup -q -n qca-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch100 -p1

%build
%cmake \
      -DQT4_BUILD=OFF \
      -DBUILD_TESTS=OFF \
      -DQCA_INSTALL_IN_QT_PREFIX=ON \
      -DWITH_botan_PLUGIN=OFF \
      -DQCA_BINARY_INSTALL_DIR:PATH="%{_bindir}" \
      -DQCA_MAN_INSTALL_DIR:PATH="%{_mandir}" \
      -Dqca_CERTSTORE="/etc/ssl/ca-bundle.pem" \
      -DQCA_SUFFIX=qt5
make %{?_smp_mflags}

%install
%cmake_install

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README COPYING TODO
%{_libdir}/libqca-qt5.so.*
%dir %{_libdir}/qt5/plugins/crypto
%{_libdir}/qt5/plugins/crypto/libqca-logger.so
%{_libdir}/qt5/plugins/crypto/libqca-softstore.so
%{_libdir}/qt5/plugins/crypto/libqca-ossl.so
%{_libdir}/qt5/plugins/crypto/libqca-gnupg.so
%{_libdir}/qt5/plugins/crypto/libqca-gcrypt.so

%files devel
%defattr(-,root,root)
%{_bindir}/qcatool-qt5
%{_bindir}/mozcerts-qt5
%{_includedir}/qt5/Qca-qt5/
%{_libdir}/qt5/mkspecs/features/crypto.prf
%{_mandir}/man1/qcatool-qt5*
%{_libdir}/libqca-qt5.so
%{_libdir}/pkgconfig/qca2-qt5.pc
%{_libdir}/cmake/Qca-qt5/

%files plugins
%defattr(-,root,root)
%{_libdir}/qt5/plugins/crypto/libqca-cyrus-sasl.so
%{_libdir}/qt5/plugins/crypto/libqca-nss.so
%if %{with pkcs11}
%{_libdir}/qt5/plugins/crypto/libqca-pkcs11.so
%endif

%changelog
* Wed Dec 27 2017 jengelh@inai.de
- Diversify subpackage descriptions.
* Wed Dec 20 2017 fabian@ritter-vogt.de
- Add patches to support OpenSSL 1.1.0:
  * 0001-Revert-tlsunittest-disable-some-ciphers.patch
  * 0002-Disable-missed-openssl-cipher-suites.patch
  * 0003-Add-support-for-OpenSSL-1.1.0.patch
- Fix provides in main package
* Thu Oct 19 2017 meissner@suse.com
- buildignore openssl-1_0_0 to avoid conflicts during the
  openssl 1.1 effort.
* Mon Oct  9 2017 vcizek@suse.com
- Hardcode certstore path on Tumbleweed, in order to avoid
  BuildRequires: ca-certificates, which will create a conflict,
  because it requires openssl-1_1_0 (bsc#1055310)
* Sun Oct  1 2017 wbauer@tmo.at
- Update to 2.1.3
  * No changelog provided
- Drop libqca-qt5-2.1.1-explicit-signed-char.patch, merged upstream
- Update Url
* Fri Sep 29 2017 wbauer@tmo.at
- Remove libbotan-devel build requirement, we explicitly disable
  building the botan plugin anyway (boo#1055322)
* Fri Aug 25 2017 fvogt@suse.com
- Force building against openSSL 1.0 (boo#1055310)
- Disable PKCS11 on TW to avoid openssl conflicts
* Wed May 25 2016 antoine.belvire@laposte.net
- Fix build on PowerPC with GCC 6:
  * Add libqca-qt5-2.1.1-explicit-signed-char.patch
* Sat Oct  3 2015 hrvoje.senjan@gmail.com
- Update to 2.1.1
  * No changelog provided
- Drop Use-Q_SLOTS-Q_SIGNALS.patch and 0001-Add-missing-QIODevice-include.patch
* Sat Sep 26 2015 hrvoje.senjan@gmail.com
- Added Use-Q_SLOTS-Q_SIGNALS.patch from upstream: allow building
  without QT_NO_KEYWORDS define
* Sat Jan 10 2015 hrvoje.senjan@gmail.com
- Update to 2.1.0.3
  * Allow co-installability with Qt4 build
- Remove conflict with libqca2-devel
- Bump required cmake version to 2.8.12
- Added ansi.diff, rh#1182200
- Added 0001-Add-missing-QIODevice-include.patch, fixes build with
  Qt 5.5
* Sat Nov  8 2014 hrvoje.senjan@gmail.com
- Update to 2.1.0
  * Ported to Qt5 (Qt4 alsa supported)
  * New building system. CMake instead of qmake
  * Added CTR symetric cipher support to qca core
  * Added no padding encryption algorithm to qca core
  * qcatool2 renamed to qcatool
  * fixed crash in qcatool when only options provided on command
    line without any commands
  * Use plugins installation path as hard-coded runtime plugins
    search path
  * Added new functiion pluginPaths
  * Added functions to get runtime QCA version
  * Fixed 'no watch file' warnings in FileWatch
  * Added EME_PKCS1v15_SSL Encryption Algorithm
  * New implementation of SafeTimer to prevent crashes
  * Updated certificates for unittests
  * RSA Keys are permutable, can encrypt with private
    and decrypt with public
  * Add unloadProvider() function for symmetry
    with insertProvider()
  * Overloaded "makeKey" to derive a password depending
    on a time factor
  * Remove pointer to deinit() routine from QCoreApplication
    at deinitialization
  * Fix a couple of crashes where all plugins
    might not be available
  * Fix operating on keys with unrelated expired subkeys
  * Fixed timers in Synchronizer class
  * Dropped randomunittest
  * Fixed many unittests
  * qca-gnupg: internal refactoring
  * qca-gnupg: try both gpg and gpg2 to find gnupg executable
  * qca-gnupg: fixed some encodings problem
  * qca-ossl: no DSA_* dl groups in FIPS specification
  * qca-ossl: added missed signatures to CRLContext
  * qca-ossl: fixed certs time zone
  * qca-nss: fixed KeyLenght for Cipher
  * qca-botan: fixed getting result size for ciphers
* Thu Aug 14 2014 hrvoje.senjan@gmail.com
- Activate libqca-qt5 package
